@@ -6,7 +6,7 @@ use warnings;
 use FlashVideo::Utils;
 use FlashVideo::JSON;
 
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 sub Version() { $VERSION; }
 
 sub find_video {
@@ -38,7 +38,7 @@ sub find_video {
 
   my @formats = map {
           { resolution => [$_->{width}, $_->{height}], url => $_->{url} }
-      } values %{ $video_data->{request}{files}{h264} };
+      } values %{ $video_data->{request}{files}{progressive} };
 
   my $preferred_quality = $prefs->quality->choose(@formats);
 
